@@ -1,7 +1,7 @@
-import urllib3
 import six
 from six.moves.urllib.parse import urlencode
 import json
+import requests
 import re
 from multiprocessing.pool import ThreadPool
 import copy
@@ -33,7 +33,6 @@ class RequestClient:
         self.api_key = api_key
 
         self.max_pool = pools_size
-        self.pool_manager = urllib3.PoolManager(num_pools=pools_size)
 
         self.is_multi = False
         self.pool = None
@@ -93,11 +92,10 @@ class RequestClient:
         timeout = None
         if _request_timeout:
             if isinstance(_request_timeout, (int, ) if six.PY3 else (int, long)):  # noqa: E501,F821
-                timeout = urllib3.Timeout(total=_request_timeout)
+                timeout = _request_timeout
             elif (isinstance(_request_timeout, tuple) and
                   len(_request_timeout) == 2):
-                timeout = urllib3.Timeout(
-                    connect=_request_timeout[0], read=_request_timeout[1])
+                timeout = (_request_timeout[0],_request_timeout[1])
 
         #set default content type
         if 'Content-Type' not in headers:
@@ -113,18 +111,16 @@ class RequestClient:
                     request_body = '{}'
                     if body is not None:
                         request_body = json.dumps(body)
-                    r = self.pool_manager.request(
+                    r = requests.request(
                         method, url,
-                        body=request_body,
-                        preload_content=_preload_content,
+                        data=request_body,
                         timeout=timeout,
                         headers=headers)
                 elif headers['Content-Type'] == 'application/x-www-form-urlencoded':  # noqa: E501
-                    r = self.pool_manager.request(
+                    r = requests.request(
                         method, url,
-                        fields=post_params,
+                        params=post_params,
                         encode_multipart=False,
-                        preload_content=_preload_content,
                         timeout=timeout,
                         headers=headers)
                 elif headers['Content-Type'] == 'multipart/form-data':
@@ -132,11 +128,10 @@ class RequestClient:
                     # Content-Type which generated by urllib3 will be
                     # overwritten.
                     del headers['Content-Type']
-                    r = self.pool_manager.request(
+                    r = requests.request(
                         method, url,
-                        fields=post_params,
+                        params=post_params,
                         encode_multipart=True,
-                        preload_content=_preload_content,
                         timeout=timeout,
                         headers=headers)
                 # Pass a `string` parameter directly in the body to support
@@ -144,10 +139,9 @@ class RequestClient:
                 # provided in serialized form
                 elif isinstance(body, str):
                     request_body = body
-                    r = self.pool_manager.request(
+                    r = requests.request(
                         method, url,
-                        body=request_body,
-                        preload_content=_preload_content,
+                        data=request_body,
                         timeout=timeout,
                         headers=headers)
                 else:
@@ -158,9 +152,9 @@ class RequestClient:
                     raise ApiException(status=0, reason=msg)
             # For `GET`, `HEAD`
             else:
-                r = self.pool_manager.request(method, url,
-                                              fields=query_params,
-                                              preload_content=_preload_content,
+                r = requests.request(method, url,
+                                              params=query_params,
+
                                               timeout=timeout,
                                               headers=headers)
         except Exception as e:
